dmaikjsit

This package provides a collection of pre-implemented "Dmai codes".

It provides a simple command-line tool to copy all the codes directly into your current project folder.

Installation

pip install dmaikjsit


This installation only needs to be done once. It adds the get-dmai-codes command to your system.

Usage

Open your command shell (cmd, PowerShell, Terminal).

cd to any directory where you want the codes.

cd C:\Users\YourName\MyProject


Run the command:

get-dmai-codes


All of the "Dmai codes" will be instantly copied into your C:\Users\YourName\MyProject folder.